==> qtjambi-designer-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiDesigner/QDesignerContainerExtension_shell.h <==
#ifndef QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H
#define QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/container.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerContainerExtension_shell : public QDesignerContainerExtension, public QtJambiShellInterface
{
public:
    QDesignerContainerExtension_shell();
    ~QDesignerContainerExtension_shell() override;

    void addWidget(QWidget* widget0) override;
    bool canAddWidget() const override;
    bool canRemove(int index0) const override;
    int count() const override;
    int currentIndex() const override;
    void insertWidget(int index0, QWidget* widget1) override;
    void remove(int index0) override;
    void setCurrentIndex(int index0) override;
    QWidget* widget(int index0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerContainerExtension_access : public QDesignerContainerExtension
{
    void __qt_addWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jboolean __qt_canAddWidget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canRemove_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_insertWidget_int_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0, QtJambiNativeID widget1);
    void __qt_remove_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    void __qt_setCurrentIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    jobject __qt_widget_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
};

#endif // QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H

==> qtjambi-designer-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiDesigner/QDesignerContainerExtension_shell.h <==
#ifndef QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H
#define QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtDesigner/container.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QVariant>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QDesignerContainerExtension_shell : public QDesignerContainerExtension, public QtJambiShellInterface
{
public:
    QDesignerContainerExtension_shell();
    ~QDesignerContainerExtension_shell() override;

    void addWidget(QWidget* widget0) override;
    bool canAddWidget() const override;
    bool canRemove(int index0) const override;
    int count() const override;
    int currentIndex() const override;
    void insertWidget(int index0, QWidget* widget1) override;
    void remove(int index0) override;
    void setCurrentIndex(int index0) override;
    QWidget* widget(int index0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerContainerExtension_access : public QDesignerContainerExtension
{
    void __qt_addWidget_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID widget0);
    jboolean __qt_canAddWidget_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_canRemove_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_currentIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_insertWidget_int_QWidget_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0, QtJambiNativeID widget1);
    void __qt_remove_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    void __qt_setCurrentIndex_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0);
    jobject __qt_widget_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
};

#endif // QDESIGNERCONTAINEREXTENSION_IMPL_SHELL_H
